{% extends "admin/delete_confirmation.html" %}
{% load static %}

{% block extrahead %}
    {{ block.super }}
    <meta content="width=device-width, initial-scale=1.0" name="viewport" />
    <link href="https://fonts.googleapis.com/css?family=Dosis:300,400,700" rel="stylesheet">
    <script src="{% static 'baton/app/dist/baton.min.js' %}"></script>
    <!-- <script src="http://localhost:8080/dist/baton.min.js"></script> -->
    <script>
        (function ($, undefined) {
            $(window).on('load', function () {
                if (!Baton.initialized) {
                    Baton.init({
                        api: {
                            app_list: '{% url 'baton-app-list-json' %}'
                        }
                    });
                }
            })
        })(jQuery, undefined)
    </script>
{% endblock %}

{% block content %}
<div class="delete-confirmation-content">
    {{ block.super }}
</div>
{% endblock %}
