// scss-lint:disable IdSelector PlaceholderInExtend NestingDepth QualifyingElement SelectorDepth ImportantRule
.passwordchange,
.auth-user.change-form {
  #content-main > form {
    @extend %admin-form;
    background: $passwordchange-bg;
    border: 1px solid $passwordchange-border-color;

    .form-row {
      align-items: flex-start;
      display: flex;
      flex-direction: row;
      flex-wrap: wrap;

      .errorlist {
        background: $field-row-error-bg;
        width: 100%;
      }
    }
  }
}
