@import 'variables';
@import '~bootstrap/scss/bootstrap';
$fa-font-path: '~font-awesome/fonts';
@import '~font-awesome/scss/font-awesome';
@import 'placeholders';
@import 'main';
@import 'login';
@import 'navbar';
@import 'footer';
@import 'menu';
@import 'dashboard';
@import 'breadcrumbs';
@import 'content';
@import 'changelist';
@import 'changeform';
@import 'changehistory';
@import 'pagination';
@import 'delete_confirmation';
@import 'passwordchange';
@import 'actionresult';
@import 'calendarclock';
@import 'analytics';
@import 'filer';
