// scss-lint:disable IdSelector PlaceholderInExtend NestingDepth QualifyingElement SelectorDepth ImportantRule
body[class=" baton-ready"] #content-main > .module {
  @extend .p-3;
  @extend .table-responsive;
  background: $changehistory-bg;
  border: 1px solid $changehistory-border-color;

  #change-history {
    @extend .table;
    @extend .table-bordered;
  }
}
