body {
  opacity: 0;
  transition: opacity .2s linear;

  &.baton-ready {
    opacity: 1;
  }
}

button,
input,
optgroup,
select,
textarea {
  font-family: $font-family-sans-serif;
}

.clear {
  clear: both;
}
